@@ -103,6 +103,7 @@ def download_artifact(artifact_host, artifact_port, remote_path, project_id, ori
             logger.info(f"download artifacts response status is {response.status}")
 
             if response.status != 200:
+                logger.error(f"download artifacts failed, response status is {response.status}, data is {response.read()}")
                 raise Exception("download artifact failed")
 
             while True:
@@ -179,13 +180,17 @@ def handle_artifacts(source_file_path, target_dir, source_sub_folder=None):
     return True
 
 
-def create_new_release_dir(release_root_dir, max_history_release_count=5):
+def create_new_release_dir(release_root_dir):
     # release dir like: 20210514175142
     release_dir = datetime.datetime.now().strftime("%Y%m%d%H%M%S")
     release_dir = os.path.join(release_root_dir, release_dir)
     if not os.path.exists(release_dir):
         os.makedirs(release_dir)
 
+    return release_dir
+
+
+def rotate_release_dir(release_root_dir, max_history_release_count=5):
     # sort release dir name match like 20210514175142 and make sure release dir is a dir
     # keep latest max_history_release_count release dir
     release_dir_list = [os.path.join(release_root_dir, release_dir_name) for release_dir_name in os.listdir(release_root_dir) if
@@ -198,8 +203,6 @@ def create_new_release_dir(release_root_dir, max_history_release_count=5):
         for dir in release_dir_list[max_history_release_count:]:
             shutil.rmtree(dir)
 
-    return release_dir
-
 
 def link_current_to_new_release(link_current_symbol, target_release_dir):
     # if symbolic exists, remove it
@@ -220,16 +223,21 @@ def handle_extra_links(args):
     # create all the link symbolics
     link_list = args.extra_symbolics
 
-    for link in link_list:
-        link_symbolic, source_path = link.split(":")
 
-        # prefix args.project_dir to source_path and link_symbolic
-        link_symbolic = os.path.join(args.project_dir, link_symbolic)
-        source_path = os.path.join(args.project_dir, source_path)
+    try:
+        for link in link_list:
+            link_symbolic, source_path = link.split(":")
 
-        if os.path.islink(link_symbolic):
-            os.remove(link_symbolic)
-        os.symlink(source_path, link_symbolic)
+            # prefix args.project_dir to source_path and link_symbolic
+            link_symbolic = os.path.join(args.project_dir, link_symbolic)
+            source_path = os.path.join(args.project_dir, source_path)
+
+            if os.path.islink(link_symbolic):
+                os.remove(link_symbolic)
+            os.symlink(source_path, link_symbolic)
+    except Exception as error:
+        print(f"create extra link failed, error is {error}")
+        exit(1)
 
 
 def restart_docker_container(args):
